﻿#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

struct Edge {
    int u, v;
    long long weight;
    bool operator<(const Edge& other) const {
        return weight < other.weight;
    }
};


class UnionFind {
public:
    UnionFind(int n) : parent(n), rank(n, 0) {
        for (int i = 0; i < n; ++i) {
            parent[i] = i;
        }
    }

    int find(int u) {
        if (u != parent[u]) {
            parent[u] = find(parent[u]);
        }
        return parent[u];
    }

    bool unite(int u, int v) {
        int rootU = find(u);
        int rootV = find(v);
        if (rootU != rootV) {
            if (rank[rootU] > rank[rootV]) {
                parent[rootV] = rootU;
            }
            else if (rank[rootU] < rank[rootV]) {
                parent[rootU] = rootV;
            }
            else {
                parent[rootV] = rootU;
                rank[rootU]++;
            }
            return true;
        }
        return false;
    }

private:
    vector<int> parent;
    vector<int> rank;
};

int main() {
    int n;
    cin >> n;

    vector<vector<long long>> dist(n, vector<long long>(n));
    vector<Edge> edges;


    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            cin >> dist[i][j];
            if (i < j) {  
                edges.push_back({ i, j, dist[i][j] });
            }
        }
    }


    sort(edges.begin(), edges.end());


    UnionFind uf(n);
    vector<vector<long long>> treeDist(n, vector<long long>(n, 1e18)); 
    for (int i = 0; i < n; ++i) treeDist[i][i] = 0;

    int edgesUsed = 0;
    for (const auto& edge : edges) {
        if (uf.unite(edge.u, edge.v)) {
            treeDist[edge.u][edge.v] = treeDist[edge.v][edge.u] = edge.weight;
            edgesUsed++;
            if (edgesUsed == n - 1) break;
        }
    }


    for (int k = 0; k < n; ++k) {
        for (int i = 0; i < n; ++i) {
            for (int j = 0; j < n; ++j) {
                if (treeDist[i][j] > treeDist[i][k] + treeDist[k][j]) {
                    treeDist[i][j] = treeDist[i][k] + treeDist[k][j];
                }
            }
        }
    }


    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            if (dist[i][j] != treeDist[i][j]) {
                cout << "No" << endl;
                return 0;
            }
        }
    }

    cout << "Yes" << endl;
    return 0;
}
