#include <iostream>
#include <algorithm>
#include <vector>
#include <iomanip>
#include <map>
#include <set>
#include <fstream>
#include <string>
#include <bitset>
#include <ctime>
#include <random>
#include <iterator>
#include <cmath>
#include <queue>
#include <deque>
#include <time.h>
 
using namespace std;
 
#define all(a) a.begin(), a.end()
#define rsort(a) sort(a, [&](auto b, auto c) {return b > c;})
 
ifstream fin("input.txt");
ofstream fout("output.txt");
 
using ll = long long;
using ld = long double;
using ull = unsigned long long;
 
ll const inf = 1e18;
 
template <class T>
istream& operator>> (istream& in, vector<T>& a)
{
	for (T& e : a)
		in >> e;
	return in;
}
 
template <class T>
ostream& operator<< (ostream& out, const vector<T>& a)
{
	for (const T& e : a)
		out << e << " ";
	return out;
}
 
template<class T, class N> auto min(T a, N b)
{
	return sizeof(a) > sizeof(b) ? min(a, (T)b) : min((N)a, b);
}
 
template<class T, class N> auto max(T a, N b)
{
	return sizeof(a) > sizeof(b) ? max(a, (T)b) : max((N)a, b);
}
 
const ll mod = 998244353;
 
ll bin_pow_mod(ll a, ll n)
{
	ll res = 1;
	while (n)
	{
		if (n & 1)
		{
			res *= a;
			res %= mod;
		}
 
		n >>= 1;
		a *= a;
		a %= mod;
	}
 
	return res;
}
 
ll bin_pow(ll a, ll n)
{
	ll res = 1;
	while (n)
	{
		if (n & 1)
		{
			res *= a;
		}
 
		n >>= 1;
		a *= a;
	}
 
	return res;
}
 
ll gcd(ll a, ll b)
{
	while (b)
	{
		a %= b;
		swap(a, b);
	}
	return a;
}
 
random_device rd;
mt19937 mersenne(rd());

void solve();
 
// #define TIME
#define ONCE
 
signed main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);
	cout.tie(0);
 
	ll TT = 1;
#ifndef ONCE 
	cin >> TT;
#endif
	while (TT--)
	{
#ifdef TIME
		clock_t start, end;
 
		start = clock();
#endif
		solve();
#ifdef TIME
		end = clock();
 
		cerr << "\ntime: " << ((double)end - start) / ((double)CLOCKS_PER_SEC) << " s\n";
#endif
		cerr << '\n';
	}
	return 0;
}

ll true_mod(ll a, ll m) {
	if (m < 0) {
		m *= -1;
	}
	return ((a % m) + m) % m;
}
ll true_div(ll a, ll m) {
	return (a - true_mod(a , m)) / m;
}

bool verify(vector<ll>& vs, vector<vector<ll>>& mat)
{
	ll k = vs.size();
	if (k == 1)
	{
		return true;
	}
	ll i = vs[0], j = vs[1];
	for (int ti = 0; ti < k; ++ti)
	{
		for (int tj = ti + 1; tj < k; ++tj)
		{
			if (mat[vs[ti]][vs[tj]] < mat[i][j])
			{
				i = vs[ti];
				j = vs[tj];
			}
		}
	}

	vector<ll> vi = vector<ll>(), vj = vector<ll>();
	for (int ts = 0; ts < k; ++ts)
	{
		ll s = vs[ts];
		if (mat[i][s] < mat[j][s])
		{
			if (mat[j][s] != mat[i][j] + mat[i][s])
			{
				return false;
			}
			vi.push_back(s);
		}
		else if (mat[i][s] > mat[j][s])
		{
			if (mat[i][s] != mat[i][j] + mat[j][s])
			{
				return false;
			}
			vj.push_back(s);
		}
		else
		{
			return false;
		}
	}

	bool bothOk = verify(vi, mat) && verify(vj, mat);
	if (!bothOk)
	{
		return false;
	}
	for (auto a : vi)
	{
		for (auto b : vj)
		{
			if (mat[a][b] != mat[a][i] + mat[i][j] + mat[j][b])
			{
				return false;
			}
		}
	}
	return true;
}

void solve() 
{
	ll n; cin >> n;
	vector<vector<ll>> mat(n, vector<ll>(n, 0));
	cin >> mat;

	for (int i = 0; i < n; ++i)
	{
		if (mat[i][i] != 0)
		{
			cout << "No\n";
			return;
		}
		for (int j = 0; j < n; ++j)
		{
			if (mat[i][j] != mat[j][i])
			{
				cout << "No\n";
				return;
			}
		}
	}
	vector<ll> vs;
	for (int i = 0; i < n; ++i)
	{
		vs.push_back(i);
	}
	if (verify(vs, mat))
	{
		cout << "Yes\n";
	}
	else
	{
		cout << "No\n";
	}
}
