#define _CRT_SECURE_NO_WARNINGS

#include <iostream>
#include <set>
#include <map>
#include <algorithm>
#include <vector>
#include <string>
#include <queue>
#include <climits>

using namespace std;

const int SZ = 1e3 + 10, LOG = 20;

vector<int> tin(SZ), tout(SZ);
vector<vector<pair<int, long long>>> t(SZ);
vector<vector<int>> up(SZ, vector<int>(LOG));
vector<long long> dist(SZ);

int timer = 0;
void dfs(int v, int p = 0, long long dst = 0) {
    dist[v] = dst;
    tin[v] = ++timer;
    up[v][0] = p;
    for (int i = 1; i < LOG; ++i)
        up[v][i] = up[up[v][i - 1]][i - 1];
    for (size_t i = 0; i < t[v].size(); ++i) {
        int to = t[v][i].first;
        if (to != p)
            dfs(to, v, dst + t[v][i].second);
    }
    tout[v] = ++timer;
}

bool upper(int a, int b) {
    return tin[a] <= tin[b] && tout[a] >= tout[b];
}

int lca(int a, int b) {
    if (upper(a, b))  return a;
    if (upper(b, a))  return b;
    for (int i = LOG - 1; i >= 0; --i)
        if (!upper(up[a][i], b))
            a = up[a][i];
    return up[a][0];
}

int main()
{
#ifdef _DEBUG
    freopen("input.txt", "r", stdin);
#endif
    ios::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    int n;
    cin >> n;
    vector<vector<long long>> matrix(n, vector<long long>(n));
    for (int i = 0; i < n; i++)
        for (int j = 0; j < n; j++)
            cin >> matrix[i][j];

    vector<vector<pair<int, long long>>> g(n);
    for (int i = 0; i < n; ++i)
        for (int j = i + 1; j < n; ++j) {
            g[i].push_back({ j, matrix[i][j] });
            g[j].push_back({ i, matrix[i][j] });
        }

    set<pair<long long, int>> q; // ,  
    vector<long long> d(n, 1e18);
    vector<int> parent(n, -1); // 
    d[0] = 0;
    q.insert(make_pair(0, 0));

    while (!q.empty()) {
        int v = q.begin()->second;
        q.erase(q.begin());

        for (auto e : g[v]) {
            int u = e.first, w = e.second;
            if (w < d[u]) {
                q.erase({ d[u], u });
                d[u] = w;
                parent[u] = v;
                q.insert({ d[u], u });
            }
        }
    }

    for (int i = 0; i < n; i++)
        if (parent[i] != -1)
            t[parent[i]].push_back({ i, matrix[i][parent[i]] });
    dfs(0);

    for (int v = 0; v < n; v++) {
        for (int u = v + 1; u < n; u++) {
            if (matrix[v][u] != dist[v] + dist[u] - 2 * dist[lca(v, u)]) {
                cout << "No";
                return 0;
            }
        }
    }
    cout << "Yes";
    return 0;
};