//#pragma GCC optimize("O3,unroll-loops,no-stack-protector")
//#pragma GCC target("avx2,avx,sse,sse2,sse3,ssse3,sse4,abm,mmx")
//#pragma GCC march("native")

#include <iostream>
#include <cmath>
#include <vector> 
#include <string>
#include <algorithm>
#include <utility>

#include <queue>
#include <set>
#include <map>
#include <unordered_set>
#include <unordered_map>
#include <cassert>

using namespace std;

template <typename T1, typename T2>
ostream& operator<<(ostream& os, pair<T1, T2> p) {
    os << "(" << p.first << ", " << p.second << ")";
    return os;
} 

template<typename T>
ostream& operator<<(ostream& os, vector<T>& v) {
    for (T& x : v) os << x << " ";
    return os;
}

template<typename T1, typename T2>
ostream& operator<<(ostream& os, map<T1,T2>& m) {
    for (auto& p : m) os << "{" << p.first << "," << p.second << "} ";
    return os;
}

struct DSU {
    int n;
    vector<int> p;
    vector<int> sz;



    DSU(int n) {
        this->n = n;
        p.assign(n, 0);
        sz.assign(n, 0);
        for (int i = 0; i < n; ++i) {
            p[i] = i;
            sz[i] = 1;
        }
    }

    int root(int v) {
        if (v == p[v]) return v;
        return p[v] = root(p[v]);
    }

    void unite(int u, int v) {
        u = root(u);
        v = root(v);
        if (u == v) return;
        if (sz[u] > sz[v]) swap(u, v);
        p[u] = v;
        sz[v] += sz[u];
    }

    bool is_connect(int u, int v) {
        return p[u] == p[v];
    }
};

int main() {
    std::ios::sync_with_stdio(false);
    std::cin.tie(0);
    std::cout.tie(0);
    cout.setf(ios::fixed);
    cout.precision(10);

    int n;
    cin >> n;
    vector<vector<int>> a(n, vector<int>(n));
    vector<pair<long long, pair<int, int>>> edges_sorted;
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < n; j++) {
            cin >> a[i][j];
            if (i != j) edges_sorted.push_back({a[i][j], {i, j}});
        }
    }
    sort(edges_sorted.begin(), edges_sorted.end());

    vector<vector<int>> calculating(n, vector<int>(n, -1));
    for (int i = 0; i < n; i++) calculating[i][i] = 0;
    DSU dsu(n);
    for (auto& e : edges_sorted) {
        int w = e.first, i = e.second.first, j = e.second.second;
        //cout << i << " " << j << " " << w << " " << calculating[i][j] << " " << a[i][j] << endl;
        if (calculating[i][j] == -1) {
            vector<int> v_i, v_j;
            int r_i = dsu.root(i), r_j = dsu.root(j);
            assert(r_i != r_j);
            for (int v = 0; v < n; v++) {
                int r = dsu.root(v);
                if (r == r_i) v_i.push_back(v);
                if (r == r_j) v_j.push_back(v);
            }
            //cout << v_i << endl << v_j << endl;
            for (int u : v_i) {
                for (int v : v_j) {
                    calculating[u][v] = calculating[u][i] + w + calculating[j][v];
                    calculating[v][u] = calculating[u][v];
                }
            }
            dsu.unite(r_i, r_j);
        } else {
            if (w != calculating[i][j]) {
                cout << "No" << endl;
                return 0;
            }
        }
    }
    cout << "Yes" << endl;
}