#include <iostream>
#include <string>
#include <random>
using namespace std;

struct Node {
    char val;
    int prior, size;
    char min_char;
    Node *left, *right;
    Node(char v) : val(v), prior(rand()), size(1), min_char(v), left(nullptr), right(nullptr) {}
};

int getSize(Node* t) {
    return t ? t->size : 0;
}

char getMin(Node* t) {
    return t ? t->min_char : '9' + 1;
}

void update(Node* t) {
    if (t) {
        t->size = 1 + getSize(t->left) + getSize(t->right);
        t->min_char = min({t->val, getMin(t->left), getMin(t->right)});
    }
}

void split(Node* t, int key, Node*& left, Node*& right, int add = 0) {
    if (!t) {
        left = right = nullptr;
        return;
    }
    int cur_key = add + getSize(t->left);
    if (key <= cur_key) {
        split(t->left, key, left, t->left, add);
        right = t;
    } else {
        split(t->right, key, t->right, right, add + 1 + getSize(t->left));
        left = t;
    }
    update(t);
}

void merge(Node*& t, Node* left, Node* right) {
    if (!left || !right)
        t = left ? left : right;
    else if (left->prior > right->prior) {
        merge(left->right, left->right, right);
        t = left;
    } else {
        merge(right->left, left, right->left);
        t = right;
    }
    update(t);
}

char queryMin(Node* t, int l, int r, int add = 0) {
    if (!t) return '9' + 1;
    int cur_key = add + getSize(t->left);
    if (r < cur_key)
        return queryMin(t->left, l, r, add);
    else if (l > cur_key)
        return queryMin(t->right, l, r, cur_key + 1);
    else {
        char res = t->val;
        if (l < cur_key)
            res = min(res, queryMin(t->left, l, r, add));
        if (r > cur_key)
            res = min(res, queryMin(t->right, l, r, cur_key + 1));
        return res;
    }
}

int findPos(Node* t, char c, int l, int r, int add = 0) {
    if (!t) return -1;
    int cur_key = add + getSize(t->left);
    if (cur_key < l)
        return findPos(t->right, c, l, r, cur_key + 1);
    else if (cur_key > r)
        return findPos(t->left, c, l, r, add);
    else {
        if (t->val == c)
            return cur_key;
        int pos_left = findPos(t->left, c, l, r, add);
        if (pos_left != -1)
            return pos_left;
        return findPos(t->right, c, l, r, cur_key + 1);
    }
}

void printTreap(Node* t) {
    if (!t) return;
    printTreap(t->left);
    cout << t->val;
    printTreap(t->right);
}

int main() {
#ifdef LOCAL
    freopen("in.txt", "r", stdin);
#endif
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    srand(42);

    int t;
    cin >> t;
    while (t--) {
        string s;
        long long k;
        cin >> s >> k;
        int n = s.size();
        Node* root = nullptr;
        for (char c : s) {
            Node* node = new Node(c);
            merge(root, root, node);
        }

        for (int i = 0; i < n && k > 0; ++i) {
            int rem = getSize(root) - i;
            int max_pos = n - 1;
            char min_c = queryMin(root, i, n - 1);
            int pos = findPos(root, min_c, i, n - 1);
            int cost = pos - i;
            if (cost > k) continue;
            if (pos == i) continue;
            Node *left, *mid, *right;
            split(root, pos + 1, mid, right);
            split(mid, i, left, mid);
            Node *first, *rest;
            split(mid, pos - i, mid, rest);
            merge(mid, rest, mid);
            merge(mid, mid, right);
            merge(root, left, mid);
            k -= cost;
        }
        printTreap(root);
        cout << '\n';
    }
    return 0;
}