#include <iostream>
#include <unordered_map>
#include <tuple>
#include <cstdint>
#include <algorithm>
 
using namespace std;
 
const uint64_t MOD = 998244353;
using ll = uint64_t;
using State = tuple<ll, ll, ll, int>;
 
struct StateHasher {
    size_t operator()(const State& state) const {
        size_t h1 = hash<ll>{}(get<0>(state));
        size_t h2 = hash<ll>{}(get<1>(state));
        size_t h3 = hash<ll>{}(get<2>(state));
        size_t h4 = hash<int>{}(get<3>(state));
 
        size_t seed = 0;
        seed ^= h1 + 1000000007 + (seed << 6) + (seed >> 2);
        seed ^= h2 + 0x9e3779b9 + (seed << 6) + (seed >> 2);
        seed ^= h3 + 1000000007 + (seed << 6) + (seed >> 2);
        seed ^= h4 + 1000000007 + (seed << 6) + (seed >> 2);
        return seed;
    }
};
 
struct StateEqual {
    bool operator() (const State& lhs, const State& rhs) const {
        return lhs == rhs;
    }
};
 
unordered_map<State, ll, StateHasher, StateEqual> memo;
 
ll dp(ll r, ll g, ll b, int last_color) {
    if (r + g + b == 0)
        return 1;
 
    State key = make_tuple(r, g, b, last_color);
    if (memo.count(key))
        return memo[key];
 
    ll res = 0;
    if (last_color != 0 && r > 0)
        res = (res + dp(r - 1, g, b, 0)) % MOD;
    if (last_color != 1 && g > 0)
        res = (res + dp(r, g - 1, b, 1)) % MOD;
    if (last_color != 2 && b > 0)
        res = (res + dp(r, g, b - 1, 2)) % MOD;
 
    memo[key] = res;
    return res;
}
 
int main() {
    ll r, g, b;
    cin >> r >> g >> b;
 
    ll counts[3] = {r, g, b};
    ll n = r + g + b;
    sort(counts, counts + 3);
    if (counts[2] > counts[0] + counts[1] + 1) {
        cout << 0 << endl;
    } else {
        memo.clear();
        memo.rehash(n*n);
        ll result = 0;
        if (r > 0)
            result = (result + dp(r - 1, g, b, 0)) % MOD;
        if (g > 0)
            result = (result + dp(r, g - 1, b, 1)) % MOD;
        if (b > 0)
            result = (result + dp(r, g, b - 1, 2)) % MOD;
        cout << result << endl;
    }
    return 0;
}