#include <algorithm>
#include <iomanip>
#include <iostream>
#include <vector>
#include <set>
#include <queue>

using namespace std;

typedef long long ll;
typedef long double ld;

ll bin_pow(ll a, ll n) {
    if (n == 0) return 1;
    if (n % 2 == 1) return bin_pow(a, n - 1) * a;
    ll b = bin_pow(a, n / 2);
    return b * b;
}

ll gcd(ll a, ll b) {
    while (a && b) {
        if (a > b) a %= b;
        else b %= a;
    }
    return a + b;
}

struct point {
    ll x, y;
};

point get(point a, point b) {
    return {b.x - a.x, b.y - a.y};
}

ll operator*(point a, point b) {
    return a.x * b.y - a.y * b.x;
}

struct dsu {
    vector <int> p, r;
    dsu(int n) {
        p.resize(n), r.resize(n, 0);
        for (int i = 0; i < n; i++) p[i] = i;
    }

    int get(int x) {
        if (x == p[x]) return x;
        return p[x] = get(p[x]);
    }

    bool join(int x, int y) {
        x = get(x), y = get(y);
        if (x == y) return false;
        if (r[x] < r[y]) swap(x, y);
        if (r[x] == r[y]) r[x]++;
        p[y] = x;
        return true;
    }

};

struct st {
    int x, i, j;
};

bool comp(st a, st b) {
    return a.x < b.x;
}

void solve() {
    int n; cin >> n;
    vector <vector <int>> a(n, vector <int> (n));
    vector <st> b;
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < n; j++) {
            cin >> a[i][j];
            if (i < j) {
                b.push_back({a[i][j], i, j});
            }
        }
    }
    sort(b.begin(), b.end(), comp);
    dsu x(n);
    vector <vector <pair <int, int>>> g(n);
    int cnt = 0;
    for (int i = 0; i < b.size(); i++) {
        if (x.join(b[i].i, b[i].j)) {
            g[b[i].i].push_back({b[i].x, b[i].j});
            g[b[i].j].push_back({b[i].x, b[i].i});
            cnt++;
        }
    }
    if (cnt != n - 1) { cout << "No"; return; }
    for (int i = 0; i < n; i++) {
        vector <int> d(n, -1);
        queue <int> q;
        d[i] = 0;
        q.push(i);
        while (!q.empty()) {
            int v = q.front(); q.pop();
            for (auto j : g[v]) {
                if (d[j.second] == -1) {
                    d[j.second] = d[v] + j.first;
                    q.push(j.second);
                }
            }
        }
        for (int j = 0; j < n; j++) {
            if (d[j] != a[i][j]) {
                cout << "No"; return;
            }
        }
    }
    cout << "Yes";
}

int main() {
    int t = 1;
    //cin >> t;
    while (t--) solve();
}
